# Better Boto

## Description

Better Boto aims to reduce the burden of using AWS Boto3.  AWS Boto3 is a low level SDK for interacting with AWS Services 
and sometimes it feels too low level or too crud like.

Better Boto is a collection of helper functions to make using AWS Boto easier.  For example, it added a create_or_update
method to the AWS CloudFormation client.  It also provides some helpers for dealing with pagination operations and some
help using AWS Organizations.  Check out the [docs](https://better-boto.readthedocs.io/en/latest/) for the full set of examples.


## Badges

[![Codacy Badge](https://api.codacy.com/project/badge/Grade/186212a8957b42a594ec8aa5f8d8a70c)](https://www.codacy.com/app/eamonnfaherty/better-boto?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=eamonnfaherty/better-boto&amp;utm_campaign=Badge_Grade)

[![Build Status](https://travis-ci.org/eamonnfaherty/better-boto.svg?branch=master)](https://travis-ci.org/eamonnfaherty/better-boto)

[![Docs Status](https://readthedocs.org/projects/better-boto/badge/?version=latest)](https://better-boto.readthedocs.io/en/latest/)
